#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

from iobase.exception import NotFoundError
from product_conf.devinfo import VOL_INFO, USB_HDD_DEV_LIST

REMOVABLE_SHARE_LIST = [
    vol
    for vol
    in VOL_INFO.keys()
    if VOL_INFO[vol]["dev"] in USB_HDD_DEV_LIST]


def _is_replication(node):

    try:
        return node.get_node("replication").is_enabled()
    except NotFoundError:
        return False


def _is_replication_host(node):

    if node.get_value("replication/host"):
        return True
    return False


def _is_replication_share(node):

    if node.get_value("replication/share"):
        return True
    return False


def _is_replication_passwd(node):

    if node.get_value("replication/passwd", do_strip=False):
        return True
    return False


def _is_replication_removable_share(node):

     share_name = node.get_value("name")
     if share_name in REMOVABLE_SHARE_LIST:
         return True
     return False


def rule_replication(node):

    if _is_replication(node):
        if not _is_replication_host(node):
            return False
        if not _is_replication_share(node):
            return False
        if not _is_replication_passwd(node):
            return False
        if _is_replication_removable_share(node):
            return False
    return True
