#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""FAL command for handling Shares Ctrl event"""

from ionas.request import Entry
from iobase.exception import ExecError
import libevh.evhcmd as evhcmd
import fal_info
from product_conf.reqinfo import Results, ReqTypes


SHARES_PATH = "eventinfo/shares"
REPLICATION_PATH = SHARES_PATH + "/share/replication"


class EvhRepRepDel(evhcmd.EvhCmd):
    """Shares Ctrl Event Handler command implementation class."""

    #
    # Request handlers
    #

    def __delete_log(self, sharename):
        try:
            import os
            path = "/mnt/sataraid1/replication/%s" % sharename
            if os.path.exists(path):
                os.remove(path)
            return True
        except:
            return False

    def __event_handler(self, entry):
        """Handle "event" request."""

        entry.set_result(Results.OK)
        sharename = entry.get().get_value("eventinfo/shares/share/name", None)
        if sharename is not None:
            if self.send_entry(
                    Entry("delete", """<replication>
                        <sharelist>
                            <share>
                                <name>%s</name>
                            </share>
                        </sharelist>
                    </replication>""" % sharename),
                    fal_info.FAL_REPLICATION_PATH).get_result() != Results.OK:
                entry.set_result(Results.INTERNAL_ERROR)
            if not self.__delete_log(sharename):
                entry.set_result(Results.INTERNAL_ERROR)
        else:
            entry.set_result(Results.INTERNAL_ERROR)

        return entry

    def __init__(self):
        """Constructor."""

        evhcmd.EvhCmd.__init__(self, evhcmd.EvhCmdOption())

        self.set_handler(ReqTypes.EVENT, self.__event_handler)

#
# Main
#

if __name__ == "__main__":
    EvhRepRepDel().handle_request()
