# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from project.fal.command import Command
from ionas.request import Entry, XmlConfNode
from fal_info import Results
import datetime


def dict__get(dictionary, path, default=None):
    try:
        k, p = path[0], path[1:]
        if p:
            return dict__get(dictionary[k], p, default=default)
        else:
            return dictionary[k]
    except:
        return default

def xmlnode__is_enabled(xmlnode, xpath=u".", default=False):
    try:
        return xmlnode.get_node(xpath).is_enabled()
    except:
        return default

def xmlnode__get_attrs(xmlnode, xpath=u".", default={}):
    try:
        return xmlnode.get_node(xpath).get_attrs()
    except:
        return default

def _to_bool(true_or_false):
    try:
        return {
            u"true": True,
            u"false": False,
        }[true_or_false]
    except:
        return False


class FALcReplication(Command):

    try:
        from fal_info import FAL_REPLICATION_PATH as COMMAND
    except:
        COMMAND_NAME = "fal_replication.py"

    def load(self):

        entry = self._load()

        data = dict()
        try:
            replication_node = entry.get()
            data = {
                "schedule": {
                    "weekly": {
                        "enabled": xmlnode__is_enabled(replication_node, "schedule/weekly"),
                        "weekdays": dict([(day, _to_bool(true_or_false)) for day, true_or_false in xmlnode__get_attrs(replication_node, "schedule/weekly/weekdays").iteritems()]),
                        "time": datetime.time(int(replication_node.get_value("schedule/weekly/time/hour", "0")),
                                              int(replication_node.get_value("schedule/weekly/time/minute", "0"))),
                    },
                },
            }
        except:
            pass
        return data

    def save(self, data, log=True, messages={}):

        __default_messages = {
            Results.OK: ["MSG_REPLICATION_CHANGE", {}],
            None: ["ERR_REPLICATION_CHANGE", {}]
        }
        __default_messages.update(messages)

        try:
            entry = self._save(data)
            result = getattr(entry, "get_result", lambda: None)()
            message = __default_messages.get(result, __default_messages[None])
            self._set_message(message[0], arglist=message[1], log=log)
            return result in [Results.OK]
        except:
            return False

    def _load(self):
        entry = Entry("load", """<replication/>""")
        return self.request(entry)

    def _save(self, data):
        """
        data = {
            "schedule": {
                "weekly": {
                    "enabled": bool,
                    "weekdays": {
                        "sun": bool,
                        "mon": bool,
                        "tue": bool,
                        "wed": bool,
                        "thu": bool,
                        "fri": bool,
                        "sat": bool,
                    },
                    "time": datetime.time,
                },
            },
        }
        """

        entry = Entry("apply",
                      """<replication>
                        <schedule>
                            <weekly>
                                <weekdays/>
                                <time>
                                    <hour/>
                                    <minute/>
                                </time>
                            </weekly>
                        </schedule>
                      </replication>""".replace("\n", "").replace(" ", ""))
        replication_node = entry.get()
        replication_node.get_node("schedule/weekly").enable(dict__get(data, ["schedule", "weekly", "enabled"], default=False))
        replication_node.get_node("schedule/weekly/weekdays").set_attrs(dict([(k, str(v).lower()) for k, v in dict__get(data, ["schedule", "weekly", "weekdays"], default={}).iteritems()]))
        schedule_weekly_time = dict__get(data, ["schedule", "weekly", "time"], default=None)
        schedule_weekly_time = schedule_weekly_time if isinstance(schedule_weekly_time, datetime.time) else datetime.time(0, 0)
        replication_node.get_node("schedule/weekly/time/hour").set_text(str(schedule_weekly_time.hour))
        replication_node.get_node("schedule/weekly/time/minute").set_text(str(schedule_weekly_time.minute))

        return self.request(entry)

if __name__ == u"__main__":
    pass
